@@ -14,22 +14,22 @@ class InventoryLineItems(Record):
 		super().__init__()
 
 
-	def get_product(self):
+	def get_product_name(self):
 		"""
-		The method to get the product
+		The method to get the product_name
 
 		Returns:
 			LineItemProduct: An instance of LineItemProduct
 		"""
 
-		return self.get_key_value('product')
+		return self.get_key_value('Product_Name')
 
-	def set_product(self, product):
+	def set_product_name(self, product_name):
 		"""
-		The method to set the value to product
+		The method to set the value to product_name
 
 		Parameters:
-			product (LineItemProduct) : An instance of LineItemProduct
+			product_name (LineItemProduct) : An instance of LineItemProduct
 		"""
 
 		try:
@@ -37,10 +37,10 @@ class InventoryLineItems(Record):
 		except Exception:
 			from .line_item_product import LineItemProduct
 
-		if product is not None and not isinstance(product, LineItemProduct):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: product EXPECTED TYPE: LineItemProduct', None, None)
+		if product_name is not None and not isinstance(product_name, LineItemProduct):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: product_name EXPECTED TYPE: LineItemProduct', None, None)
 		
-		self.add_key_value('product', product)
+		self.add_key_value('Product_Name', product_name)
 
 	def get_quantity(self):
 		"""
@@ -50,7 +50,7 @@ class InventoryLineItems(Record):
 			float: A float representing the quantity
 		"""
 
-		return self.get_key_value('quantity')
+		return self.get_key_value('Quantity')
 
 	def set_quantity(self, quantity):
 		"""
@@ -63,7 +63,7 @@ class InventoryLineItems(Record):
 		if quantity is not None and not isinstance(quantity, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: quantity EXPECTED TYPE: float', None, None)
 		
-		self.add_key_value('quantity', quantity)
+		self.add_key_value('Quantity', quantity)
 
 	def get_discount(self):
 		"""
@@ -96,7 +96,7 @@ class InventoryLineItems(Record):
 			float: A float representing the total_after_discount
 		"""
 
-		return self.get_key_value('total_after_discount')
+		return self.get_key_value('Total_After_Discount')
 
 	def set_total_after_discount(self, total_after_discount):
 		"""
@@ -109,7 +109,7 @@ class InventoryLineItems(Record):
 		if total_after_discount is not None and not isinstance(total_after_discount, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: total_after_discount EXPECTED TYPE: float', None, None)
 		
-		self.add_key_value('total_after_discount', total_after_discount)
+		self.add_key_value('Total_After_Discount', total_after_discount)
 
 	def get_net_total(self):
 		"""
@@ -119,7 +119,7 @@ class InventoryLineItems(Record):
 			float: A float representing the net_total
 		"""
 
-		return self.get_key_value('net_total')
+		return self.get_key_value('Net_Total')
 
 	def set_net_total(self, net_total):
 		"""
@@ -132,30 +132,30 @@ class InventoryLineItems(Record):
 		if net_total is not None and not isinstance(net_total, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: net_total EXPECTED TYPE: float', None, None)
 		
-		self.add_key_value('net_total', net_total)
+		self.add_key_value('Net_Total', net_total)
 
-	def get_book(self):
+	def get_price_book_name(self):
 		"""
-		The method to get the book
+		The method to get the price_book_name
 
 		Returns:
-			float: A float representing the book
+			float: A float representing the price_book_name
 		"""
 
-		return self.get_key_value('book')
+		return self.get_key_value('Price_Book_Name')
 
-	def set_book(self, book):
+	def set_price_book_name(self, price_book_name):
 		"""
-		The method to set the value to book
+		The method to set the value to price_book_name
 
 		Parameters:
-			book (float) : A float representing the book
+			price_book_name (float) : A float representing the price_book_name
 		"""
 
-		if book is not None and not isinstance(book, float):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: book EXPECTED TYPE: float', None, None)
+		if price_book_name is not None and not isinstance(price_book_name, float):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: price_book_name EXPECTED TYPE: float', None, None)
 		
-		self.add_key_value('book', book)
+		self.add_key_value('Price_Book_Name', price_book_name)
 
 	def get_tax(self):
 		"""
@@ -188,7 +188,7 @@ class InventoryLineItems(Record):
 			float: A float representing the list_price
 		"""
 
-		return self.get_key_value('list_price')
+		return self.get_key_value('List_Price')
 
 	def set_list_price(self, list_price):
 		"""
@@ -201,7 +201,7 @@ class InventoryLineItems(Record):
 		if list_price is not None and not isinstance(list_price, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: list_price EXPECTED TYPE: float', None, None)
 		
-		self.add_key_value('list_price', list_price)
+		self.add_key_value('List_Price', list_price)
 
 	def get_unit_price(self):
 		"""
@@ -257,7 +257,7 @@ class InventoryLineItems(Record):
 			float: A float representing the total
 		"""
 
-		return self.get_key_value('total')
+		return self.get_key_value('Total')
 
 	def set_total(self, total):
 		"""
@@ -270,30 +270,30 @@ class InventoryLineItems(Record):
 		if total is not None and not isinstance(total, float):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: total EXPECTED TYPE: float', None, None)
 		
-		self.add_key_value('total', total)
+		self.add_key_value('Total', total)
 
-	def get_product_description(self):
+	def get_description(self):
 		"""
-		The method to get the product_description
+		The method to get the description
 
 		Returns:
-			string: A string representing the product_description
+			string: A string representing the description
 		"""
 
-		return self.get_key_value('product_description')
+		return self.get_key_value('Description')
 
-	def set_product_description(self, product_description):
+	def set_description(self, description):
 		"""
-		The method to set the value to product_description
+		The method to set the value to description
 
 		Parameters:
-			product_description (string) : A string representing the product_description
+			description (string) : A string representing the description
 		"""
 
-		if product_description is not None and not isinstance(product_description, str):
-			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: product_description EXPECTED TYPE: str', None, None)
+		if description is not None and not isinstance(description, str):
+			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: description EXPECTED TYPE: str', None, None)
 		
-		self.add_key_value('product_description', product_description)
+		self.add_key_value('Description', description)
 
 	def get_line_tax(self):
 		"""
@@ -303,7 +303,7 @@ class InventoryLineItems(Record):
 			list: An instance of list
 		"""
 
-		return self.get_key_value('line_tax')
+		return self.get_key_value('Line_Tax')
 
 	def set_line_tax(self, line_tax):
 		"""
@@ -316,4 +316,4 @@ class InventoryLineItems(Record):
 		if line_tax is not None and not isinstance(line_tax, list):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: line_tax EXPECTED TYPE: list', None, None)
 		
-		self.add_key_value('line_tax', line_tax)
+		self.add_key_value('Line_Tax', line_tax)
