@@ -122,7 +122,11 @@ class Converter(ABC):
                 classes = interface_details[Constants.CLASSES]
                 check = False
                 for each_class in classes:
-                    if value.__class__.__module__.lower() == str(each_class):
+                    path_split = str(value.__class__.__module__).rpartition(".")
+                    class_name = Converter.module_to_class(path_split[-1])
+                    pack = path_split[0] + "." + class_name
+
+                    if pack == each_class:
                         check = True
                         break
             else:
@@ -250,3 +254,16 @@ class Converter(ABC):
         encoded_string = base64.b64encode(input_bytes)
         encoded_string = str(encoded_string.decode("UTF-8"))
         return encoded_string + '.json'
+
+    @staticmethod
+    def module_to_class(module_name):
+        class_name = module_name
+
+        if "_" in module_name:
+            class_name = ''
+            module_split = str(module_name).split('_')
+            for each_name in module_split:
+                each_name = each_name.capitalize()
+                class_name += each_name
+
+        return class_name
\ No newline at end of file
